"""narrate — Local text-to-speech with Kokoro and Chatterbox engines.

Usage::

    from narrate import narrate

    # Quick TTS (uses default engine and voice)
    narrate("Hello world")

    # Choose voice (second positional argument)
    narrate("Hello world", "am_adam")        # male voice
    narrate("Hello world", "bf_emma")        # British female
    narrate("Hello world", "af_heart")       # warm female (default)

    # Keyword style
    narrate("Hello world", voice="af_sarah", speed=1.2)

    # Choose engine
    narrate("Hello world", engine="kokoro")
    narrate("Hello world", engine="chatterbox")

    # Save to file without playing
    narrate("Hello world", output="hello.wav", play=False)

    # Chatterbox with emotion control
    narrate("Hello world", engine="chatterbox", emotion=0.8)

    # List available voices
    from narrate import list_voices
    print(list_voices())
"""

__version__ = "0.1.1"

from narrate.core import narrate, set_engine, set_voice, list_voices, list_engines

__all__ = ["narrate", "set_engine", "set_voice", "list_voices", "list_engines"]
